/* readme.h
 */
#ifndef OSL_MISC_README_H
#define OSL_MISC_README_H

namespace osl
{
  /**
   * 特に将棋と関係ない基礎的なコード
   */
  namespace misc
  {
  } // namespace misc
} // namespace osl

#endif /* _README_H */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
